sagemath_doc_pdf: SageMath documentation in PDF format
======================================================

Upon installation, this package builds the SageMath documentation
in PDF format.

It is an optional package.  It can be enabled at configuration time
using ``./configure --enable-sagemath_doc_pdf``.  Alternatively,
it can be installed by using ``make doc-pdf``.
